==> _private_core_network-1.2.25.tar.gz: lib/network_resources/model/the_movie_credit.dart <==
class TheMovieCredit {
  int? id;
  List<TheMovieCast>? cast;
  List<TheMovieCrew>? crew;

  TheMovieCredit({this.id, this.cast, this.crew});

  TheMovieCredit.fromJson(Map<String, dynamic> json) {
    id = json["id"];
    cast = json["cast"] == null
        ? null
        : (json["cast"] as List).map((e) => TheMovieCast.fromJson(e)).toList();
    crew = json["crew"] == null
        ? null
        : (json["crew"] as List).map((e) => TheMovieCrew.fromJson(e)).toList();
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["id"] = id;
    if (cast != null) {
      _data["cast"] = cast?.map((e) => e.toJson()).toList();
    }
    if (crew != null) {
      _data["crew"] = crew?.map((e) => e.toJson()).toList();
    }
    return _data;
  }

  TheMovieCredit copyWith({
    int? id,
    List<TheMovieCast>? cast,
    List<TheMovieCrew>? crew,
  }) =>
      TheMovieCredit(
        id: id ?? this.id,
        cast: cast ?? this.cast,
        crew: crew ?? this.crew,
      );
}

class TheMovieCrew {
  bool? adult;
  int? gender;
  int? id;
  String? knownForDepartment;
  String? name;
  String? originalName;
  num? popularity;
  dynamic profilePath;
  String? creditId;
  String? department;
  String? job;

  TheMovieCrew(
      {this.adult,
      this.gender,
      this.id,
      this.knownForDepartment,
      this.name,
      this.originalName,
      this.popularity,
      this.profilePath,
      this.creditId,
      this.department,
      this.job});

  TheMovieCrew.fromJson(Map<String, dynamic> json) {
    adult = json["adult"];
    gender = json["gender"];
    id = json["id"];
    knownForDepartment = json["known_for_department"];
    name = json["name"];
    originalName = json["original_name"];
    popularity = json["popularity"];
    profilePath = json["profile_path"];
    creditId = json["credit_id"];
    department = json["department"];
    job = json["job"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["adult"] = adult;
    _data["gender"] = gender;
    _data["id"] = id;
    _data["known_for_department"] = knownForDepartment;
    _data["name"] = name;
    _data["original_name"] = originalName;
    _data["popularity"] = popularity;
    _data["profile_path"] = profilePath;
    _data["credit_id"] = creditId;
    _data["department"] = department;
    _data["job"] = job;
    return _data;
  }

  TheMovieCrew copyWith({
    bool? adult,
    int? gender,
    int? id,
    String? knownForDepartment,
    String? name,
    String? originalName,
    num? popularity,
    dynamic profilePath,
    String? creditId,
    String? department,
    String? job,
  }) =>
      TheMovieCrew(
        adult: adult ?? this.adult,
        gender: gender ?? this.gender,
        id: id ?? this.id,
        knownForDepartment: knownForDepartment ?? this.knownForDepartment,
        name: name ?? this.name,
        originalName: originalName ?? this.originalName,
        popularity: popularity ?? this.popularity,
        profilePath: profilePath ?? this.profilePath,
        creditId: creditId ?? this.creditId,
        department: department ?? this.department,
        job: job ?? this.job,
      );
}

class TheMovieCast {
  bool? adult;
  int? gender;
  int? id;
  String? knownForDepartment;
  String? name;
  String? originalName;
  num? popularity;
  String? profilePath;
  int? castId;
  String? character;
  String? creditId;
  int? order;

  TheMovieCast(
      {this.adult,
      this.gender,
      this.id,
      this.knownForDepartment,
      this.name,
      this.originalName,
      this.popularity,
      this.profilePath,
      this.castId,
      this.character,
      this.creditId,
      this.order});

  TheMovieCast.fromJson(Map<String, dynamic> json) {
    adult = json["adult"];
    gender = json["gender"];
    id = json["id"];
    knownForDepartment = json["known_for_department"];
    name = json["name"];
    originalName = json["original_name"];
    popularity = json["popularity"];
    profilePath = json["profile_path"];
    castId = json["cast_id"];
    character = json["character"];
    creditId = json["credit_id"];
    order = json["order"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["adult"] = adult;
    _data["gender"] = gender;
    _data["id"] = id;
    _data["known_for_department"] = knownForDepartment;
    _data["name"] = name;
    _data["original_name"] = originalName;
    _data["popularity"] = popularity;
    _data["profile_path"] = profilePath;
    _data["cast_id"] = castId;
    _data["character"] = character;
    _data["credit_id"] = creditId;
    _data["order"] = order;
    return _data;
  }

  TheMovieCast copyWith({
    bool? adult,
    int? gender,
    int? id,
    String? knownForDepartment,
    String? name,
    String? originalName,
    num? popularity,
    String? profilePath,
    int? castId,
    String? character,
    String? creditId,
    int? order,
  }) =>
      TheMovieCast(
        adult: adult ?? this.adult,
        gender: gender ?? this.gender,
        id: id ?? this.id,
        knownForDepartment: knownForDepartment ?? this.knownForDepartment,
        name: name ?? this.name,
        originalName: originalName ?? this.originalName,
        popularity: popularity ?? this.popularity,
        profilePath: profilePath ?? this.profilePath,
        castId: castId ?? this.castId,
        character: character ?? this.character,
        creditId: creditId ?? this.creditId,
        order: order ?? this.order,
      );
}

==> _private_core_network-1.3.48.tar.gz: lib/network_resources/model/the_movie_credit.dart <==
class TheMovieCredit {
  int? id;
  List<TheMovieCast>? cast;
  List<TheMovieCrew>? crew;

  TheMovieCredit({this.id, this.cast, this.crew});

  TheMovieCredit.fromJson(Map<String, dynamic> json) {
    id = json["id"];
    cast = json["cast"] == null
        ? null
        : (json["cast"] as List).map((e) => TheMovieCast.fromJson(e)).toList();
    crew = json["crew"] == null
        ? null
        : (json["crew"] as List).map((e) => TheMovieCrew.fromJson(e)).toList();
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["id"] = id;
    if (cast != null) {
      data["cast"] = cast?.map((e) => e.toJson()).toList();
    }
    if (crew != null) {
      data["crew"] = crew?.map((e) => e.toJson()).toList();
    }
    return data;
  }

  TheMovieCredit copyWith({
    int? id,
    List<TheMovieCast>? cast,
    List<TheMovieCrew>? crew,
  }) =>
      TheMovieCredit(
        id: id ?? this.id,
        cast: cast ?? this.cast,
        crew: crew ?? this.crew,
      );
}

class TheMovieCrew {
  bool? adult;
  int? gender;
  int? id;
  String? knownForDepartment;
  String? name;
  String? originalName;
  num? popularity;
  dynamic profilePath;
  String? creditId;
  String? department;
  String? job;

  TheMovieCrew(
      {this.adult,
      this.gender,
      this.id,
      this.knownForDepartment,
      this.name,
      this.originalName,
      this.popularity,
      this.profilePath,
      this.creditId,
      this.department,
      this.job});

  TheMovieCrew.fromJson(Map<String, dynamic> json) {
    adult = json["adult"];
    gender = json["gender"];
    id = json["id"];
    knownForDepartment = json["known_for_department"];
    name = json["name"];
    originalName = json["original_name"];
    popularity = json["popularity"];
    profilePath = json["profile_path"];
    creditId = json["credit_id"];
    department = json["department"];
    job = json["job"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["adult"] = adult;
    data["gender"] = gender;
    data["id"] = id;
    data["known_for_department"] = knownForDepartment;
    data["name"] = name;
    data["original_name"] = originalName;
    data["popularity"] = popularity;
    data["profile_path"] = profilePath;
    data["credit_id"] = creditId;
    data["department"] = department;
    data["job"] = job;
    return data;
  }

  TheMovieCrew copyWith({
    bool? adult,
    int? gender,
    int? id,
    String? knownForDepartment,
    String? name,
    String? originalName,
    num? popularity,
    dynamic profilePath,
    String? creditId,
    String? department,
    String? job,
  }) =>
      TheMovieCrew(
        adult: adult ?? this.adult,
        gender: gender ?? this.gender,
        id: id ?? this.id,
        knownForDepartment: knownForDepartment ?? this.knownForDepartment,
        name: name ?? this.name,
        originalName: originalName ?? this.originalName,
        popularity: popularity ?? this.popularity,
        profilePath: profilePath ?? this.profilePath,
        creditId: creditId ?? this.creditId,
        department: department ?? this.department,
        job: job ?? this.job,
      );
}

class TheMovieCast {
  bool? adult;
  int? gender;
  int? id;
  String? knownForDepartment;
  String? name;
  String? originalName;
  num? popularity;
  String? profilePath;
  int? castId;
  String? character;
  String? creditId;
  int? order;

  TheMovieCast(
      {this.adult,
      this.gender,
      this.id,
      this.knownForDepartment,
      this.name,
      this.originalName,
      this.popularity,
      this.profilePath,
      this.castId,
      this.character,
      this.creditId,
      this.order});

  TheMovieCast.fromJson(Map<String, dynamic> json) {
    adult = json["adult"];
    gender = json["gender"];
    id = json["id"];
    knownForDepartment = json["known_for_department"];
    name = json["name"];
    originalName = json["original_name"];
    popularity = json["popularity"];
    profilePath = json["profile_path"];
    castId = json["cast_id"];
    character = json["character"];
    creditId = json["credit_id"];
    order = json["order"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["adult"] = adult;
    data["gender"] = gender;
    data["id"] = id;
    data["known_for_department"] = knownForDepartment;
    data["name"] = name;
    data["original_name"] = originalName;
    data["popularity"] = popularity;
    data["profile_path"] = profilePath;
    data["cast_id"] = castId;
    data["character"] = character;
    data["credit_id"] = creditId;
    data["order"] = order;
    return data;
  }

  TheMovieCast copyWith({
    bool? adult,
    int? gender,
    int? id,
    String? knownForDepartment,
    String? name,
    String? originalName,
    num? popularity,
    String? profilePath,
    int? castId,
    String? character,
    String? creditId,
    int? order,
  }) =>
      TheMovieCast(
        adult: adult ?? this.adult,
        gender: gender ?? this.gender,
        id: id ?? this.id,
        knownForDepartment: knownForDepartment ?? this.knownForDepartment,
        name: name ?? this.name,
        originalName: originalName ?? this.originalName,
        popularity: popularity ?? this.popularity,
        profilePath: profilePath ?? this.profilePath,
        castId: castId ?? this.castId,
        character: character ?? this.character,
        creditId: creditId ?? this.creditId,
        order: order ?? this.order,
      );
}
